@@ -11,12 +11,12 @@ module.exports =
           source: "/install.sh",
           destination:
             "https://raw.githubusercontent.com/railwayapp/nixpacks/main/install.sh",
-          permanent: true,
+            permanent: false,
         },
         {
             source: "/install.ps1",
             destination: "https://raw.githubusercontent.com/railwayapp/nixpacks/main/install.ps1",
-            permanent: true
+            permanent: false,
         }
       ];
     },
